@@ -39,7 +39,7 @@ from PyQt5.QtCore import QSettings
 from fslib import ui_filepicker, __version__
 from fslib.utils import root_url, human_readable_info, match_extension, \
     FOLDER_SPACES, FILES_SPACES, WidgetImage, get_extension_from_string,\
-    fs_url_exists, fs_file_exists, who_called_me
+    fs_url_exists, who_called_me
 from fslib.icons import icons
 
 
@@ -63,10 +63,7 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         if isinstance(fs_url, list):
             self.fs_url = fs_url[0]
             if isinstance(stored_fs_url, list):
-                for _fs_url in stored_fs_url:
-                    if fs_url_exists(_fs_url):
-                        self.ui_fs_serverlist.addItem(_fs_url)
-                for _fs_url in fs_url:
+                for _fs_url in list(set(stored_fs_url + fs_url)):
                     if fs_url_exists(_fs_url):
                         self.ui_fs_serverlist.addItem(_fs_url)
         else:
@@ -196,7 +193,9 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         if ok:
             if fs_url_exists(fs_url):
                 self.ui_fs_serverlist.setVisible(True)
-                self.ui_fs_serverlist.addItem(fs_url)
+                all_urls = [self.ui_fs_serverlist.item(idx).text() for idx in range(self.ui_fs_serverlist.count())]
+                if fs_url not in all_urls:
+                    self.ui_fs_serverlist.addItem(fs_url)
                 self.save_settings()
             else:
                 msg = u'"%s" Url not valid' % fs_url
@@ -352,9 +351,9 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         self.ui_FileList.setItem(index, 1, QtWidgets.QTableWidgetItem(_size))
         self.ui_FileList.setItem(index, 2, QtWidgets.QTableWidgetItem(_mod_time))
 
-    def get_info(self, _item):
+    def get_info(self, _item, namespaces=[u'details', u'access', u'stat']):
         try:
-            info = self.fs.getinfo(_item, namespaces=[u'details', u'access', u'stat'])
+            info = self.fs.getinfo(_item, namespaces=namespaces)
             time.sleep(0.001)
         except (fs.errors.ResourceNotFound, UnicodeEncodeError):
             info = None
@@ -450,7 +449,8 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
             self.filename = u""
         if self.filename != u"":
             self.ui_SelectedName.setText(self.filename)
-            if fs_file_exists(self.selected_dir, self.filename):
+            info = self.get_info(self.filename, namespaces=None)
+            if info is not None and info.is_file:
                 self.ui_Action.setEnabled(True)
 
     def cancel(self):
@@ -533,26 +533,25 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         Action on Open / Save button
         """
         self.filename = self.ui_SelectedName.text()
-        if self.filename == u"":
+        if self.filename == u"" or self.filename is None:
             return
 
-        if self.filename is not None:
-            dirname = fs.path.forcedir(u'.')
-            if self.wparm is not None:
-                dirname = self.selected_dir
-            if dirname.startswith(self.active_url):
-                filename = u"{}{}".format(fs.path.forcedir(self.active_url), self.filename)
-            else:
-                # We can't use fs.path.join and also not fs.path.abspath because of protocol url
-                filename = u"{}{}{}".format(fs.path.forcedir(self.active_url),
-                                            fs.path.forcedir(dirname), self.filename)
-            filename = filename.replace(fs.path.forcedir(u'.'), u'')
+        dirname = fs.path.forcedir(u'.')
+        if self.wparm is not None:
+            dirname = self.selected_dir
+        if dirname.startswith(self.active_url):
+            filename = u"{}{}".format(fs.path.forcedir(self.active_url), self.filename)
+        else:
+            # We can't use fs.path.join and also not fs.path.abspath because of protocol url
+            filename = u"{}{}{}".format(fs.path.forcedir(self.active_url),
+                                        fs.path.forcedir(dirname), self.filename)
+        filename = filename.replace(fs.path.forcedir(u'.'), u'')
         if self.show_save_action and not self.show_dirs_only:
             self.save_settings()
             self.filename = self.ui_SelectedName.text()
             if self.filename == u"":
                 return
-            info = self.get_info(fs.path.split(filename)[1])
+            info = self.get_info(fs.path.split(filename)[1], namespaces=None)
             if info is not None and info.is_dir:
                 sel = QtWidgets.QMessageBox.warning(
                     self, u"Warning",
